# Changelog
Versions follow [Semantic Versioning](https://semver.org/spec/v2.0.0.html) (`<major>`.`<minor>`.`<patch>`)

## [v0.1.1]
### Fixed
* Fix incorrect entry point for `csvdatetrim`

## [v0.1.0]
Initial release 🎉
### Added
* Add `sco1_misc.prompts`, helper wrappers for [`Tkinter`'s selection dialogs](https://docs.python.org/3/library/dialog.html)
* Add `csvdatetrim`, a CLI tool for date windowing CSV log files
